@@ -9,13 +9,13 @@
 __author__ = 'TROUVERIE Joachim'
 
 import os.path as op
-from os import makedirs
+from os import makedirs, symlink
 from flask import Flask
 from flask.ext.flatpages import FlatPages
 from flask.ext.pagedown import PageDown
 from flask.ext.login import LoginManager
 from flask.ext.babel import Babel
-from flask.ext.themes2 import Themes
+from flask.ext.themes2 import Themes, load_themes_from
 
 # create app
 app = Flask(__name__)
@@ -32,6 +32,11 @@ path =  op.join(op.dirname(__file__), 'content')
 if not op.exists(path) :
     makedirs(op.join(path, 'pages'))
     makedirs(op.join(path, 'posts'))
+path = op.join(op.expanduser('~'), '.microbe')
+theme_path =  op.join(op.dirname(__file__), 'themes')
+if not op.exists(path) :
+    makedirs(path)
+    symlink(theme_path, op.join(path, 'themes'))
 
 # flatpages
 pages = FlatPages(app)
@@ -48,7 +53,17 @@ lm.login_view = 'admin.login'
 babel = Babel(app)
 
 # themes support
-Themes(app, app_identifier = 'microbe')
+def load_themes(app) :
+    """
+    Themes loader
+    """
+    path = op.join(op.dirname(__file__), 'themes')
+    if op.isdir(path) :
+        return load_themes_from(path)
+    else :
+        return ()
+
+Themes(app, app_identifier = 'microbe', loaders = [load_themes])
 
 # blueprint
 from admin import bp as admin_module
