@@ -287,6 +287,8 @@ def media() :
     List media available to contents
     """
     path = op.join(op.abspath(op.dirname(__file__)), 'static', 'media')
+    if not op.exists(path) :
+        os.makedirs(path)
     files = [File(f) for f in os.listdir(path)]
     # pagination
     try :
@@ -342,6 +344,7 @@ def themes() :
     """
     List available themes
     """
+    current_app.theme_manager.refresh()
     themes = get_themes_list()
     selected = session.get(u'theme', current_app.config[u'DEFAULT_THEME'])
     return render_template('admin/themes.html', themes = themes, 
